Page 126 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 126

Home

    We don't have a profreedom foreign policy, carried
    out by the United States State Department or the United
    States Government which really benefits those who want
    to overthrow Communism and bring about freedom. Our
    policy has been geared toward helping salvage, and
    helping to bail out the Communist regimes, which are
    corrupt, and which are economic disasters.”

    used to withhold the truth of what was going on in the
    Soviet Union and Eastern Europe, this control is now
    being used to deceive millions of uninformed people into
    believing that everything has now changed, that the
    leaders in the Soviet Union are no longer Communists,
    but are now Socialists. We are told that these former

    Communists, overnight, out of the goodness of their
    hearts, decided to embrace capitalism and allow religious
    freedom. Since they are now our friends, we should
    supply them with massive amounts of foreign aid and

    support the "good guys" who are working against the
    "bad guys" in that country.

    According to Anitoliy Golitsyn, the highest level
    Soviet official ever to escape to the West, this turnabout
    by Communist leaders is a total fraud, planned far in
    advance to deceive the West. Details of this planned
    deception are given in Mr. Golitsyn's book New Lies For
    Old. His book is available from General Birch Services,

    P. O. Box 8040, Appleton, Wisconsin.
    Golitsyn's view is also shared by Ambassador
    Funderburk:

    121

    Babylon's War Against God

    Just as the CFR's control over the mass media was